pub enum RingBufferError {
BufferFull,
PayloadLengthMismatch,
InvalidPayloadOffset,
}Expand description
Errors that can occur while writing into a PluginRingBuffer.
Examples
use martensite_plugin::RingBufferError;
let err = RingBufferError::BufferFull;
assert_eq!(err.to_string(), "ring buffer is full");Variants
BufferFull
The ring buffer does not have enough contiguous free space for the command and its payload.
PayloadLengthMismatch
The command’s data_len field does not match the supplied payload.
InvalidPayloadOffset
The command’s payload_offset or data_len is outside the buffer.